==> Decompiler-0.0.37-sources.jar: net/covers1624/coffeegrinder/bytecode/insns/ForLoop.java <==
package net.covers1624.coffeegrinder.bytecode.insns;

import net.covers1624.coffeegrinder.bytecode.*;
import net.covers1624.coffeegrinder.bytecode.matching.LdcMatching;
import net.covers1624.coffeegrinder.type.AType;
import net.covers1624.coffeegrinder.type.PrimitiveType;
import net.covers1624.coffeegrinder.util.EnumBitSet;

/**
 * Created by covers1624 on 15/9/21.
 */
public class ForLoop extends AbstractLoop {

    private final InstructionSlot<Instruction> initializer = new InstructionSlot<>(this); // (any statement)
    private final InstructionSlot<Instruction> condition = new InstructionSlot<>(this); // returns bool
    private final InstructionSlot<BlockContainer> body = new InstructionSlot<>(this);
    private final InstructionSlot<Block> increment = new InstructionSlot<>(this); // (Statement or StatementList)

    public ForLoop(Instruction initializer, Instruction condition, BlockContainer body, Instruction increment) {
        super(InsnOpcode.FOR_LOOP);
        this.initializer.set(initializer);
        this.condition.set(condition);
        this.body.set(body);
        this.increment.set(increment);
    }

    @Override
    public AType getResultType() {
        return PrimitiveType.VOID;
    }

    @Override
    public EnumBitSet<InstructionFlag> getDirectFlags() {
        return InstructionFlag.NONE;
    }

    @Override
    protected EnumBitSet<InstructionFlag> computeFlags() {
        EnumBitSet<InstructionFlag> flags = super.computeFlags();
        if (LdcMatching.matchLdcBoolean(getCondition(), true) == null) {
            flags.clear(InstructionFlag.END_POINT_UNREACHABLE);
        }
        return flags;
    }

    @Override
    public <R, C> R accept(InsnVisitor<R, C> visitor, C ctx) {
        return visitor.visitForLoop(this, ctx);
    }

    //@formatter:off
    public Instruction getInitializer() { return initializer.get(); }
    public Instruction getCondition() { return condition.get(); }
    public Block getIncrement() { return increment.get(); }
    public void setInitializer(Instruction initializer) { this.initializer.set(initializer); }
    public void setCondition(Instruction condition) { this.condition.set(condition); }
    public void setIncrement(Block increment) { this.increment.set(increment); }
    @Override public BlockContainer getBody() { return body.get(); }
    //@formatter:on
}

==> Decompiler-0.0.52-sources.jar: net/covers1624/coffeegrinder/bytecode/insns/ForLoop.java <==
package net.covers1624.coffeegrinder.bytecode.insns;

import net.covers1624.coffeegrinder.bytecode.*;
import net.covers1624.coffeegrinder.bytecode.matching.LdcMatching;
import net.covers1624.coffeegrinder.type.AType;
import net.covers1624.coffeegrinder.type.PrimitiveType;
import net.covers1624.coffeegrinder.util.EnumBitSet;

/**
 * Created by covers1624 on 15/9/21.
 */
public final class ForLoop extends AbstractLoop {

    private final InstructionSlot<Instruction> initializer = new InstructionSlot<>(this); // (any statement)
    private final InstructionSlot<Instruction> condition = new InstructionSlot<>(this); // returns bool
    private final InstructionSlot<BlockContainer> body = new InstructionSlot<>(this);
    private final InstructionSlot<Block> increment = new InstructionSlot<>(this); // (Statement or StatementList)

    public ForLoop(Instruction initializer, Instruction condition, BlockContainer body, Instruction increment) {
        this.initializer.set(initializer);
        this.condition.set(condition);
        this.body.set(body);
        this.increment.set(increment);
    }

    @Override
    public AType getResultType() {
        return PrimitiveType.VOID;
    }

    @Override
    public EnumBitSet<InstructionFlag> getDirectFlags() {
        return InstructionFlag.NONE;
    }

    @Override
    protected EnumBitSet<InstructionFlag> computeFlags() {
        EnumBitSet<InstructionFlag> flags = super.computeFlags();
        if (LdcMatching.matchLdcBoolean(getCondition(), true) == null) {
            flags.clear(InstructionFlag.END_POINT_UNREACHABLE);
        }
        return flags;
    }

    @Override
    public <R, C> R accept(InsnVisitor<R, C> visitor, C ctx) {
        return visitor.visitForLoop(this, ctx);
    }

    //@formatter:off
    public Instruction getInitializer() { return initializer.get(); }
    public Instruction getCondition() { return condition.get(); }
    public Block getIncrement() { return increment.get(); }
    public void setInitializer(Instruction initializer) { this.initializer.set(initializer); }
    public void setCondition(Instruction condition) { this.condition.set(condition); }
    public void setIncrement(Block increment) { this.increment.set(increment); }
    @Override public BlockContainer getBody() { return body.get(); }
    //@formatter:on
}
